@@ -35,18 +35,14 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-pref("general.useragent.extra.thunderbird", "Thunderbird/1.5.0.7");
-//@line 39 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+pref("general.useragent.extra.thunderbird", "Thunderbird/2.0.0.4");
+//@line 39 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 
 pref("general.useragent.locale", "en-US");
-//@line 41 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 41 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 pref("general.skins.selectedSkin", "classic/1.0");
 
-//@line 47 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
-
-pref("update.app.enabled", true); // Whether or not app updates are enabled 
-pref("update.app.url", "chrome://mozapps/locale/update/update.properties");	
-pref("update.extensions.enabled", true);
+//@line 47 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 
 // App-specific update preferences
 
@@ -77,10 +73,10 @@ pref("app.update.vendorName.override", "Mozilla");
 
 // URL user can browse to manually if for some reason all update installation
 // attempts fail.  TODO: Change this URL
-pref("app.update.url.manual", "http://www.mozilla.org/products/thunderbird/");
+pref("app.update.url.manual", "http://%LOCALE%.www.mozilla.com/%LOCALE%/%APP%/");
 // A default value for the "More information about this update" link
 // supplied in the "An update is available" page of the update wizard. 
-pref("app.update.url.details", "chrome://messenger-region/locale/region.properties");
+pref("app.update.url.details", "http://%LOCALE%.www.mozilla.com/%LOCALE%/%APP%/releases/");
 // User-settable override to app.update.url for testing purposes.
 //pref("app.update.url.override", "");
 
@@ -104,6 +100,15 @@ pref("app.update.timer", 600000);
 // which tells users what's new in this new update.
 pref("app.update.showInstalledUI", false);
 
+// Release notes URL
+pref("app.releaseNotesURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/%APP%/%VERSION%/releasenotes/");
+
+// Blocklist preferences
+pref("extensions.blocklist.enabled", true);
+pref("extensions.blocklist.interval", 86400);
+pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/1/%APP_ID%/%APP_VERSION%/");
+pref("extensions.blocklist.detailsURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/blocklist/");
+
 // Developers can set this to |true| if they are constantly changing files in their
 // extensions directory so that the extension system does not constantly think that
 // their extensions are being updated and thus reregistered every time the app is started
@@ -119,52 +124,50 @@ pref("extensions.logging.enabled", false);
 //  .. etc ..
 //
 pref("extensions.update.enabled", true);
-pref("extensions.update.autoUpdateEnabled", true);
 pref("extensions.update.url", "chrome://mozapps/locale/extensions/extensions.properties");
-pref("extensions.update.autoUpdate", false);    // Automatically download and install 
-                                                // updates to themes and extensions. 
-                                                // Does nothing at present. 
 
 pref("extensions.update.interval", 86400);  // Check for updates to Extensions and 
                                             // Themes every week
 // Non-symmetric (not shared by extensions) extension-specific [update] preferences
-pref("extensions.getMoreExtensionsURL", "chrome://mozapps/locale/extensions/extensions.properties");
-pref("extensions.getMoreThemesURL", "chrome://mozapps/locale/extensions/extensions.properties");
-pref("extensions.update.severity.threshold", 5);// The number of pending Extension/Theme
-                                                // updates you can have before the update
-                                                // notifier goes from low->medium severity.
-pref("extensions.update.count", 0);             // The number of extension/theme/etc 
-                                                // updates available
+pref("extensions.getMoreExtensionsURL", "http://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/extensions/");
+pref("extensions.getMoreThemesURL", "http://%LOCALE%.add-ons.mozilla.com/%LOCALE%/%APP%/%VERSION%/themes/");
 pref("extensions.dss.enabled", false);          // Dynamic Skin Switching                                               
 pref("extensions.dss.switchPending", false);    // Non-dynamic switch pending after next
-                                                // restart.
-
-
-// General Update preferences
-pref("update.interval", 3600000);               // Check each of the above intervals 
-                                                // every 60 mins
-pref("update.showSlidingNotification", true);   // Windows-only slide-up taskbar 
-                                                // notification.
-// These prefs relate to the number and severity of updates available. This is a 
-// cache that the browser notification mechanism uses to determine if it should show
-// status bar UI if updates are detected and the app is shut down before installing
-// them.
-// 0 = low    (extension/theme updates), 
-// 1 = medium (numerous extension/theme updates), 
-// 2 = high   (new version of Firefox/Security patch)
-pref("update.severity", 0); 
 
 pref("xpinstall.whitelist.add", "update.mozilla.org");
 pref("xpinstall.whitelist.add.103", "addons.mozilla.org");
 
-pref("mail.phishing.detection.enabled", true); // enable / disable phishing detection for link clicks
+pref("mail.shell.checkDefaultClient", true);
 pref("mail.spellcheck.inline", true);
+pref("mail.showPreviewText", true); // enables preview text in mail alerts and folder tooltips
 
-//@line 167 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+pref("mail.biff.alert.show_preview", true);
+pref("mail.biff.alert.show_subject", true);
+pref("mail.biff.alert.show_sender",  true);
+
+// Folder Pane View
+// 0 == All Folders
+// 1 == Unread Folders
+// 2 == Favorite Folders
+// 3 == Most Recently Used Folders
+pref("mail.ui.folderpane.view", 0);
+pref("mail.folder.views.version", 0);
+
+// target folder URI used for the last move or copy
+pref("mail.last_msg_movecopy_target_uri", "");
+// last move or copy operation was a move
+pref("mail.last_msg_movecopy_was_move", true);
+
+//@line 165 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.instantApply", true);
-//@line 172 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 170 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 174 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 172 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+
+pref("accessibility.typeaheadfind", false);
+pref("accessibility.typeaheadfind.timeout", 5000);
+pref("accessibility.typeaheadfind.linksonly", false);
+pref("accessibility.typeaheadfind.flashBar", 1);
 
 /////////////////////////////////////////////////////////////////
 // Overrides of the seamonkey suite mailnews.js prefs
@@ -172,51 +175,29 @@ pref("browser.preferences.animateFadeIn", false);
 pref("mail.showFolderPaneColumns", false); // setting to true will allow total/unread/size columns
 pref("mail.showCondensedAddresses", true); // show the friendly display name for people I know
 
-/////////////////////////////////////////////////////////////////
-// Privacy Controls for Handling Remote Content
-///////////////////////////////////////////////////////////////// 
-pref("mailnews.message_display.allow.plugins", false); // disable plugins by default
-pref("mailnews.message_display.disable_remote_image", true);
-pref("mailnews.message_display.disable_remote_images.useWhitelist", true);
-pref("mailnews.message_display.disable_remote_images.whiteListAbURI","moz-abmdbdirectory://abook.mab");
-
-/////////////////////////////////////////////////////////////////
-// Trusted Mail Domains
-//
-// Specific domains can be white listed to bypass various privacy controls in Thunderbird
-// such as blocking remote images, the phishing detector, etc. This is particularly
-// useful for business deployments where images or links reference servers inside a 
-// corporate intranet. For multiple domains, separate them with a comma. i.e.
-// pref("mail.trusteddomains", "mozilla.org,mozillafoundation.org");
-///////////////////////////////////////////////////////////////// 
-pref("mail.trusteddomains", "");
-
 // hidden pref for changing how we present attachments in the message pane
-pref("mailnews.attachments.display.largeView", false); 
+pref("mailnews.attachments.display.largeView", true); 
 pref("mail.pane_config.dynamic",            0);
-pref("mailnews.display.sanitizeJunkMail", true);
+pref("mailnews.reuse_thread_window2", true);
+pref("mail.spam.display.sanitize", true); // sanitize the HTML in spam messages
 pref("mail.standalone", true); 
 pref("editor.singleLine.pasteNewlines", 4);  // substitute commas for new lines in single line text boxes
 
+// make messages available for Thunderbird's spotlight importer.
+//@line 196 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+
 // hidden pref to ensure a certain number of headers in the message pane
 // to avoid the height of the header area from changing when headers are present / not present
 pref("mailnews.headers.minNumHeaders", 0); // 0 means we ignore this pref
 
 pref("mail.compose.dontWarnMail2Newsgroup", false);
 
-pref("network.image.imageBehavior", 2);
 pref("network.cookie.cookieBehavior", 3); // 0-Accept, 1-dontAcceptForeign, 2-dontUse, 3-p3p
 
 /////////////////////////////////////////////////////////////////
 // End seamonkey suite mailnews.js pref overrides
 ///////////////////////////////////////////////////////////////// 
 
-// whether to check if we are the default mail, news or feed client
-// on startup. 
-pref("mail.checkDefaultMail", true);
-pref("mail.checkDefaultNews", false);
-pref("mail.checkDefaultFeed", false);
-
 /////////////////////////////////////////////////////////////////
 // Overrides for generic app behavior from the seamonkey suite's all.js
 /////////////////////////////////////////////////////////////////
@@ -243,6 +224,7 @@ pref("intl.menuitems.insertseparatorbeforeaccesskeys","chrome://global/locale/in
 pref("signon.rememberSignons",              true);
 pref("signon.expireMasterPassword",         false);
 pref("signon.SignonFileName",               "signons.txt");
+pref("signon.SignonFileName2",              "signons2.txt");
 
 pref("browser.hiddenWindowChromeURL", "chrome://messenger/content/hiddenWindow.xul");
 pref("network.search.url","http://cgi.netscape.com/cgi-bin/url_search.cgi?search=");
@@ -255,10 +237,21 @@ pref("general.startup.compose",             false);
 pref("general.startup.addressbook",         false);
 
 pref("offline.startup_state",            2);
+// 0 Ask before sending unsent messages when going online
+// 1 Always send unsent messages when going online
+// 2 Never send unsent messages when going online
 pref("offline.send.unsent_messages",            0);
+
+// 0 Ask before synchronizing the offline mail store when going offline
+// 1 Always synchronize the offline store when going offline
+// 2 Never synchronize the offline store when going offline
 pref("offline.download.download_messages",  0);
 pref("offline.prompt_synch_on_exit",            true);
 
+//@line 262 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+pref("offline.autoDetect", false);
+//@line 264 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+
 // Expose only select protocol handlers. All others should go
 // through the external protocol handler route.
 pref("network.protocol-handler.expose-all", false);
@@ -279,18 +272,18 @@ pref("network.protocol-handler.warn-external.ftp", false);
 pref("network.hosts.smtp_server",           "mail");
 pref("network.hosts.pop_server",            "mail");
 
-pref("security.warn_entering_secure.show_once", false);
-pref("security.warn_entering_weak.show_once", false);
-pref("security.warn_leaving_secure.show_once", false);
-pref("security.warn_viewing_mixed.show_once", false);
+pref("security.warn_entering_secure", false);
+pref("security.warn_entering_weak", false);
+pref("security.warn_leaving_secure", false);
+pref("security.warn_viewing_mixed", false);
 
 pref("general.config.obscure_value", 0); // for MCD .cfg files
 
 pref("xpinstall.dialog.confirm", "chrome://mozapps/content/xpinstall/xpinstallConfirm.xul");
-pref("xpinstall.dialog.progress.skin", "chrome://mozapps/content/extensions/extensions.xul?type=themes");
-pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/extensions.xul?type=extensions");
-pref("xpinstall.dialog.progress.type.skin", "Extension:Manager-themes"); 
-pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager-extensions");
+pref("xpinstall.dialog.progress.skin", "chrome://mozapps/content/extensions/extensions.xul");
+pref("xpinstall.dialog.progress.chrome", "chrome://mozapps/content/extensions/extensions.xul");
+pref("xpinstall.dialog.progress.type.skin", "Extension:Manager"); 
+pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager");
 
 /////////////////////////////////////////////////////////////////
 // End seamonkey suite all.js pref overrides
@@ -300,78 +293,26 @@ pref("xpinstall.dialog.progress.type.chrome", "Extension:Manager-extensions");
 // Generic browser related prefs. 
 // XXX: Need to scrub these to see which ones thunderbird really needs...
 /////////////////////////////////////////////////////////////////
-
-pref("general.open_location.last_url",      "");
-pref("general.open_location.last_window_choice", 0);
-
-// 0 = blank, 1 = home (browser.startup.homepage), 2 = last
-pref("browser.startup.page",                1);
 pref("browser.startup.homepage",	   "chrome://navigator-region/locale/region.properties");
-pref("browser.startup.homepage.count", 1);
-// "browser.startup.homepage_override" was for 4.x
-pref("browser.startup.homepage_override.1", true);
-pref("browser.startup.autoload_homepage",   true);
-
 pref("browser.cache.memory.capacity",       4096);
-
-pref("browser.urlbar.autoFill", false);
-pref("browser.urlbar.showPopup", true);
-pref("browser.urlbar.showSearch", true);
-pref("browser.urlbar.matchOnlyTyped", false);
-
 pref("browser.chrome.site_icons", true);
 pref("browser.chrome.favicons", false);
-
 pref("browser.chrome.toolbar_tips",         true);
-// 0 = Pictures Only, 1 = Text Only, 2 = Pictures and Text
-pref("browser.chrome.toolbar_style",        2);
-
 pref("browser.xul.error_pages.enabled", true);
 
-// Dialog modality issues
-pref("browser.show_about_as_stupid_modal_window", false);
-
-pref("browser.download.progressDnldDialog.keepAlive", true); // keep the dnload progress dialog up after dnload is complete
-pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", true);
+// Attachment download manager settings
+pref("mail.attachment.store.version", 0);
 pref("browser.download.useDownloadDir", false);
 pref("browser.download.folderList", 0);
-pref("browser.download.autoDownload", false);
-pref("browser.download.lastLocation", false);
-
-// various default search settings
-pref("browser.search.defaulturl", "chrome://navigator-region/locale/region.properties");
-pref("browser.search.opensidebarsearchpanel", true);
-pref("browser.search.last_search_category", "NC:SearchCategory?category=urn:search:category:1");
-pref("browser.search.mode", 0);
-// basic search popup constraint: minimum sherlock plugin version displayed
-// (note: must be a string representation of a float or it'll default to 0.0)
-pref("browser.search.basic.min_ver", "0.0");
-pref("browser.urlbar.autocomplete.enabled", true);
-pref("browser.urlbar.clickSelectsAll", true);
-
-pref("browser.history.grouping", "day");
-pref("browser.sessionhistory.max_entries", 50);
-
-// Translation service
-pref("browser.translation.service", "http://www.teletranslator.com:8120/?AlisUI=frames_ex/moz_home&alis_info=moz&AlisTargetURI=");
-pref("browser.translation.serviceDomain", "teletranslator.com");
-
-// css2 hover pref
-pref("nglayout.events.showHierarchicalHover", false);
-
-// Smart Browsing prefs
-pref("browser.related.enabled", true);
-pref("browser.related.autoload", 1);  // 0 = Always, 1 = After first use, 2 = Never
-pref("browser.related.provider", "http://www-rl.netscape.com/wtgn?");
-pref("browser.related.disabledForDomains", "");
-pref("browser.goBrowsing.enabled", true);
-
-// Default bookmark sorting
-pref("browser.bookmarks.sort.direction", "descending");
-pref("browser.bookmarks.sort.resource", "rdf:http://home.netscape.com/NC-rdf#Name");
-
-//Internet Search
-pref("browser.search.defaultenginename", "chrome://communicator-region/locale/region.properties");
+pref("browser.download.manager.showAlertOnComplete", false);
+pref("browser.download.manager.showAlertInterval", 2000);
+pref("browser.download.manager.retention", 1);
+pref("browser.download.manager.showWhenStarting", true);
+pref("browser.download.manager.useWindow", true);
+pref("browser.download.manager.closeWhenDone", true);
+pref("browser.download.manager.openDelay", 100);
+pref("browser.download.manager.focusWhenStarting", false);
+pref("browser.download.manager.flashCount", 0);
 
 pref("javascript.options.showInConsole",    true);
 
@@ -394,6 +335,9 @@ pref("news.directory",                  "");
 pref("autoupdate.enabled",              true);
 pref("browser.editor.disabled", false);
 pref("spellchecker.dictionary", "");
+// Dictionary download preference
+pref("spellchecker.dictionaries.download.url", "https://%LOCALE%.add-ons.mozilla.com/%LOCALE%/thunderbird/%VERSION%/dictionaries/");
+
 // profile.force.migration can be used to bypass the migration wizard, forcing migration from a particular
 // mail application without any user intervention. Possible values are: 
 // dogbert (4.x), seamonkey (mozilla suite), eudora, oexpress, outlook. 
@@ -402,11 +346,6 @@ pref("profile.force.migration", "");
 // Customizable toolbar stuff
 pref("custtoolbar.personal_toolbar_folder", "");
 
-pref("sidebar.customize.all_panels.url", "http://sidebar-rdf.netscape.com/%LOCALE%/sidebar-rdf/%SIDEBAR_VERSION%/all-panels.rdf");
-pref("sidebar.customize.directory.url", "http://dmoz.org/Netscape/Sidebar/");
-pref("sidebar.customize.more_panels.url", "http://dmoz.org/Netscape/Sidebar/");
-pref("sidebar.num_tabs_in_view", 8);
-
 // XXXbsmedberg why are changing the default value here?
 // ------------------
 //  Numeral Style
@@ -417,28 +356,47 @@ pref("sidebar.num_tabs_in_view", 8);
 // 4 = hindinumeralBidi
 pref("bidi.numeral", 1);
 
-pref("browser.throbber.url","chrome://navigator-region/locale/region.properties");
-
-// pref to control the alert notification 
-pref("alerts.slideIncrement", 1);
-pref("alerts.slideIncrementTime", 10);
-pref("alerts.totalOpenTime", 4000);
-pref("alerts.height", 50);
+// prefs to control the mail alert notification
+pref("alerts.slideIncrementTime", 50);
+pref("alerts.totalOpenTime", 3000);
 
 // 0 opens the download manager
 // 1 opens a progress dialog
 // 2 and other values, no download manager, no progress dialog. 
 pref("browser.downloadmanager.behavior", 1);
 
-pref("privacy.popups.sound_enabled",              true);
-pref("privacy.popups.sound_url",                  "");
-pref("privacy.popups.statusbar_icon_enabled",     true);
+// analyze urls in mail messages for scams
+pref("mail.phishing.detection.enabled", true);
+// If phishing detection is enabled, allow fine grained control
+// of the local, static tests
+pref("mail.phishing.detection.ipaddresses", true); 
+pref("mail.phishing.detection.mismatched_hosts", true);
 
-//@line 445 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+pref("browser.safebrowsing.enabled", false);
+
+// Non-enhanced mode (local url lists) URL list to check for updates
+pref("browser.safebrowsing.provider.0.updateURL", "");
+pref("browser.safebrowsing.dataProvider", 0);
+
+// Does the provider name need to be localizable?
+pref("browser.safebrowsing.provider.0.name", "");
+pref("browser.safebrowsing.provider.0.lookupURL", "");
+pref("browser.safebrowsing.provider.0.keyURL", "");
+pref("browser.safebrowsing.provider.0.reportURL", "");
+
+// HTML report pages
+pref("browser.safebrowsing.provider.0.reportGenericURL", "http://{moz:locale}.phish-generic.mozilla.com/?hl={moz:locale}");
+pref("browser.safebrowsing.provider.0.reportErrorURL", "http://{moz:locale}.phish-error.mozilla.com/?hl={moz:locale}");
+pref("browser.safebrowsing.provider.0.reportPhishURL", "http://{moz:locale}.phish-report.mozilla.com/?hl={moz:locale}");
+
+// FAQ URL
+pref("browser.safebrowsing.warning.infoURL", "http://%LOCALE%.www.mozilla.com/%LOCALE%/firefox/phishing-protection/");
+
+//@line 407 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 // For the download dialog
 pref("browser.download.progressDnldDialog.enable_launch_reveal_buttons", false);
 pref("browser.urlbar.clickSelectsAll", false);
-//@line 450 "/builds/tinderbox/Tb-Mozilla1.8.0-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
+//@line 412 "/builds/tinderbox/Tb-Mozilla1.8-Release/Linux_2.4.18-14_Depend/mozilla/mail/app/profile/all-thunderbird.js"
 
 // prevent status-bar spoofing even if people are foolish enough to turn on JS
 pref("dom.disable_window_status_change",          true);
